# Changelog

## [0.0.16a28](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a28) (2024-05-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a27...0.0.16a28)

**Implemented enhancements:**

- feat/wait\_while\_speaking [\#190](https://github.com/OpenVoiceOS/OVOS-workshop/pull/190) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a27](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a27) (2024-05-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a26...0.0.16a27)

**Fixed bugs:**

- fix/deactivate\_in\_converse/fallback [\#199](https://github.com/OpenVoiceOS/OVOS-workshop/pull/199) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a26](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a26) (2024-05-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a25...0.0.16a26)

**Fixed bugs:**

- refactor/skill\_activation\_before\_events [\#198](https://github.com/OpenVoiceOS/OVOS-workshop/pull/198) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a25](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a25) (2024-04-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a24...0.0.16a25)

**Implemented enhancements:**

- feat/units\_from\_session [\#197](https://github.com/OpenVoiceOS/OVOS-workshop/pull/197) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a24](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a24) (2024-04-09)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a23...0.0.16a24)

**Implemented enhancements:**

- feat/targeted OCP queries [\#195](https://github.com/OpenVoiceOS/OVOS-workshop/pull/195) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a23](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a23) (2024-03-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a22...0.0.16a23)

**Fixed bugs:**

- fix/converse\_intents\_no\_match [\#193](https://github.com/OpenVoiceOS/OVOS-workshop/pull/193) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a22](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a22) (2024-03-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a21...0.0.16a22)

**Fixed bugs:**

- fix/universal converse [\#192](https://github.com/OpenVoiceOS/OVOS-workshop/pull/192) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a21](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a21) (2024-03-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a20...0.0.16a21)

## [0.0.16a20](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a20) (2024-03-19)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a19...0.0.16a20)

**Implemented enhancements:**

- refactor/skill\_settings\_change [\#92](https://github.com/OpenVoiceOS/OVOS-workshop/pull/92) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a19](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a19) (2024-03-05)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a18...0.0.16a19)

**Merged pull requests:**

- Update warning log to use `log_deprecation` helper [\#188](https://github.com/OpenVoiceOS/OVOS-workshop/pull/188) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.16a18](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a18) (2024-03-04)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a17...0.0.16a18)

**Fixed bugs:**

- Add bugfix with tests for `find_resource` [\#189](https://github.com/OpenVoiceOS/OVOS-workshop/pull/189) ([NeonDaniel](https://github.com/NeonDaniel))

## [0.0.16a17](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a17) (2024-02-22)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a16...0.0.16a17)

**Fixed bugs:**

- fix: universal skills [\#187](https://github.com/OpenVoiceOS/OVOS-workshop/pull/187) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a16](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a16) (2024-02-21)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a15...0.0.16a16)

**Implemented enhancements:**

- feat/session\_location [\#186](https://github.com/OpenVoiceOS/OVOS-workshop/pull/186) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a15](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a15) (2024-02-07)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a14...0.0.16a15)

**Merged pull requests:**

- ocp metadata in init method [\#185](https://github.com/OpenVoiceOS/OVOS-workshop/pull/185) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a14](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a14) (2024-02-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a13...0.0.16a14)

**Implemented enhancements:**

- add skill ressources inventory [\#184](https://github.com/OpenVoiceOS/OVOS-workshop/pull/184) ([emphasize](https://github.com/emphasize))

**Closed issues:**

- SkillResources: add method to create resource/intent test yaml files [\#180](https://github.com/OpenVoiceOS/OVOS-workshop/issues/180)

## [0.0.16a13](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a13) (2024-01-31)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a12...0.0.16a13)

**Fixed bugs:**

- BaseSkill.schedule\_repeating\_event has wrong type annotation [\#128](https://github.com/OpenVoiceOS/OVOS-workshop/issues/128)

**Merged pull requests:**

- chore: fix type hints [\#183](https://github.com/OpenVoiceOS/OVOS-workshop/pull/183) ([mikejgray](https://github.com/mikejgray))

## [0.0.16a12](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a12) (2024-01-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a11...0.0.16a12)

**Implemented enhancements:**

- refactor/homescreen [\#182](https://github.com/OpenVoiceOS/OVOS-workshop/pull/182) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a11](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a11) (2024-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a10...0.0.16a11)

## [0.0.16a10](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a10) (2024-01-24)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a9...0.0.16a10)

**Fixed bugs:**

- fix/skill\_name [\#179](https://github.com/OpenVoiceOS/OVOS-workshop/pull/179) ([JarbasAl](https://github.com/JarbasAl))
- fix/sounds\_in\_docker [\#178](https://github.com/OpenVoiceOS/OVOS-workshop/pull/178) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a9](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a9) (2024-01-20)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a8...0.0.16a9)

**Fixed bugs:**

- fix/self.name usages [\#177](https://github.com/OpenVoiceOS/OVOS-workshop/pull/177) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a8](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a8) (2024-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a7...0.0.16a8)

**Implemented enhancements:**

- feat/stop\_per\_session [\#169](https://github.com/OpenVoiceOS/OVOS-workshop/pull/169) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a7](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a7) (2024-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a6...0.0.16a7)

## [0.0.16a6](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a6) (2024-01-12)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a5...0.0.16a6)

**Implemented enhancements:**

- feat/OCP csv keyword files support [\#174](https://github.com/OpenVoiceOS/OVOS-workshop/pull/174) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a5](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a5) (2024-01-08)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a4...0.0.16a5)

**Implemented enhancements:**

- feat/ocp\_voc\_match [\#172](https://github.com/OpenVoiceOS/OVOS-workshop/pull/172) ([NeonJarbas](https://github.com/NeonJarbas))

## [0.0.16a4](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a4) (2024-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a3...0.0.16a4)

**Fixed bugs:**

- When a skill reload fails then try and clean up [\#173](https://github.com/OpenVoiceOS/OVOS-workshop/pull/173) ([lbt](https://github.com/lbt))

## [0.0.16a3](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a3) (2024-01-06)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a2...0.0.16a3)

**Fixed bugs:**

- FallbackSkill `__new__()` fails for FallbackSkillV1 [\#170](https://github.com/OpenVoiceOS/OVOS-workshop/issues/170)
- Just publish the skill\_id without the extra ":" [\#171](https://github.com/OpenVoiceOS/OVOS-workshop/pull/171) ([lbt](https://github.com/lbt))

## [0.0.16a2](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a2) (2023-12-30)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.16a1...0.0.16a2)

**Fixed bugs:**

- fix/loading\_failure\_logs\_even\_if\_loaded [\#168](https://github.com/OpenVoiceOS/OVOS-workshop/pull/168) ([JarbasAl](https://github.com/JarbasAl))

## [0.0.16a1](https://github.com/OpenVoiceOS/OVOS-workshop/tree/0.0.16a1) (2023-12-29)

[Full Changelog](https://github.com/OpenVoiceOS/OVOS-workshop/compare/0.0.15...0.0.16a1)

**Merged pull requests:**

- packaging/update\_imports [\#167](https://github.com/OpenVoiceOS/OVOS-workshop/pull/167) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
